"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
var _web = require("../../../../server/base-http/web");
var _removeTrailingSlash = require("../../../../shared/lib/router/utils/remove-trailing-slash");
var _routeMatcher = require("../../../../server/future/route-matchers/route-matcher");
class HandlerProvider {
    constructor(route){
        this.route = route;
        this.patched = false;
        this.matcher = new _routeMatcher.RouteMatcher(route.definition);
        // If the handler doesn't need patching, mark it as already patched.
        if (!route.handler.patch) this.patched = true;
    }
    async handler(request) {
        // Patch the handler if it supports it and if it hasn't been patched yet.
        if (!this.patched) {
            var _handler, ref;
            (ref = (_handler = this.route.handler).patch) == null ? void 0 : ref.call(_handler);
            this.patched = true;
        }
        // TODO: (wyattjoh) replace with the unified request type
        const req = new _web.WebNextRequest(request);
        // Get the pathname for the matcher. Pathnames should not have trailing
        // slashes for matching.
        const pathname = (0, _removeTrailingSlash).removeTrailingSlash(new URL(request.url).pathname);
        // Get the match for this request.
        const match = this.matcher.match(pathname);
        if (!match) {
            throw new Error(`Invariant: no match found for request. Pathname '${pathname}' should have matched '${this.matcher.definition.pathname}'`);
        }
        // Create the context for the handler. This contains the params from the
        // match (if any).
        const context = {
            params: match.params,
            staticGenerationContext: {
                supportsDynamicHTML: true
            }
        };
        // Get the response from the handler.
        const response = await this.route.handler.handle(req, context);
        return response;
    }
}
exports.HandlerProvider = HandlerProvider;

//# sourceMappingURL=provider.js.map