import type { Params } from '../../../shared/lib/router/utils/route-matcher';
import type { HandlerModule } from '../route-handler-managers/route-handler-manager';
import type { NextConfig } from '../../config-shared';
import type { AppRouteRouteDefinition } from '../route-definitions/app-route-route-definition';
import type { AppConfig } from '../../../build/utils';
import type { RequestAsyncStorage } from '../../../client/components/request-async-storage';
import type { StaticGenerationAsyncStorage } from '../../../client/components/static-generation-async-storage';
import type * as ServerHooks from '../../../client/components/hooks-server-context';
import type * as HeaderHooks from '../../../client/components/headers';
import type { staticGenerationBailout as StaticGenerationBailout } from '../../../client/components/static-generation-bailout';
import { type StaticGenerationContext } from '../../async-storage/static-generation-async-storage-wrapper';
import { BaseNextRequest } from '../../base-http';
import { HTTP_METHOD } from '../../web/http';
import { RouteHandler, RouteHandlerContext } from './route-handler';
/**
 * AppRouteRouteHandlerContext is the context that is passed to the route
 * handler for app routes.
 */
export interface AppRouteRouteHandlerContext extends RouteHandlerContext {
    staticGenerationContext: StaticGenerationContext['renderOpts'];
}
/**
 * AppRouteHandlerFnContext is the context that is passed to the handler as the
 * second argument.
 */
interface AppRouteHandlerFnContext {
    params?: Params;
}
/**
 * Handler function for app routes.
 */
export declare type AppRouteHandlerFn = (
/**
 * Incoming request object.
 */
req: Request, 
/**
 * Context properties on the request (including the parameters if this was a
 * dynamic route).
 */
ctx: AppRouteHandlerFnContext) => Response;
export declare type AppRouteUserlandModule = Record<HTTP_METHOD, AppRouteHandlerFn> & Pick<AppConfig, 'dynamic' | 'revalidate' | 'dynamicParams' | 'fetchCache'> & {
    generateStaticParams?: any;
};
/**
 * AppRouteModule is the module definition for the available exports from the
 * compiled app route module.
 */
export declare type AppRouteModule = HandlerModule<AppRouteRouteDefinition, AppRouteRouteHandler, AppRouteUserlandModule>;
export interface AppRouteRouteHandlerOptions {
    readonly definition: AppRouteRouteDefinition;
    readonly userland: AppRouteUserlandModule;
    readonly resolvedPagePath: string;
    readonly nextConfigOutput: NextConfig['output'];
    readonly requestAsyncStorage: RequestAsyncStorage;
    readonly staticGenerationAsyncStorage: StaticGenerationAsyncStorage;
    readonly serverHooks: typeof ServerHooks;
    readonly headerHooks: typeof HeaderHooks;
    readonly staticGenerationBailout: typeof StaticGenerationBailout;
}
export declare class AppRouteRouteHandler implements RouteHandler {
    private readonly definition;
    private readonly userland;
    private readonly resolvedPagePath;
    private readonly nextConfigOutput;
    private readonly requestAsyncStorage;
    private readonly staticGenerationAsyncStorage;
    private readonly serverHooks;
    private readonly headerHooks;
    private readonly staticGenerationBailout;
    constructor({ definition, userland, resolvedPagePath, nextConfigOutput, requestAsyncStorage, staticGenerationAsyncStorage, serverHooks, headerHooks, staticGenerationBailout, }: AppRouteRouteHandlerOptions);
    private resolve;
    private execute;
    /**
     * When true, indicates that the global interfaces have been patched via the
     * `patch()` method.
     */
    private patched;
    /**
     * Patch will patch any global interfaces that require patching to support
     * the route handler.
     */
    patch(): void;
    handle(req: BaseNextRequest, context: AppRouteRouteHandlerContext): Promise<Response>;
}
export {};
